Developer's Guide
=================

Module contents
---------------

.. automodule:: opticalglass
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

glass
+++++

.. automodule:: opticalglass.glass
    :members:
    :undoc-members:
    :show-inheritance:

glassfactory
++++++++++++

.. automodule:: opticalglass.glassfactory
    :members:
    :undoc-members:
    :show-inheritance:

glasserror
++++++++++

.. automodule:: opticalglass.glasserror
    :members:
    :undoc-members:
    :show-inheritance:

Catalog-specific Submodules
---------------------------

cdgm
++++

.. automodule:: opticalglass.cdgm
    :members:
    :undoc-members:
    :show-inheritance:

hoya
++++

.. automodule:: opticalglass.hoya
    :members:
    :undoc-members:
    :show-inheritance:

ohara
+++++

.. automodule:: opticalglass.ohara
    :members:
    :undoc-members:
    :show-inheritance:

schott
++++++

.. automodule:: opticalglass.schott
    :members:
    :undoc-members:
    :show-inheritance:

